import swaggerJsdoc from 'swagger-jsdoc';
import {version} from '../../package.json';

const options = {
  swaggerDefinition: {
    openapi: '3.0.0',
    info: {
      title: 'Shop-API',
      version: version,
      description: 'Shop REST API'
    },
    servers: [
      {
        url: 'http://localhost:8000'
      }
    ],
    components: {
      schemas: {
        ProductDto: {
          type: 'object',
          properties: {
            title: {
              type: 'string',
              description: 'Название продукта'
            },
            description: {
              type: 'string',
              description: 'Описание продукта'
            },
            price: {
              type: 'number',
              description: 'Цена продукта'
            },
            image: {
              type: 'file',
              description: 'Картинка продукта',
              format: 'binary'
            },
            categoryId: {
              type: 'number',
              description: 'ID категории продукта'
            }
          },
          required: ['title', 'price', 'categoryId']
        },
        CategoryDto: {
          type: 'object',
          properties: {
            title: {
              type: 'string',
              description: 'Название категории'
            },
            description: {
              type: 'string',
              description: 'Описание категории'
            },
          },
          required: ['title']
        },
        StatusEnum: {
          type: 'string',
          enum: ['success', 'error', 'loading'],
          description: 'Статус оплаты'
        }
      }
    }
  },
  apis: ['src/controllers/*.ts']
};

export const specs = swaggerJsdoc(options);