import { CategoryService } from '@/services/category.service';
import { RequestHandler } from 'express';
import { plainToInstance } from 'class-transformer';
import { CategoryDto } from '@/dto/category.dto';

export class CategoryController {
  private service: CategoryService;

  constructor() {
    this.service = new CategoryService();
  }

  /**
   * @swagger
   * /categories:
   *    get:
   *      summary: Получить список категорий
   *      tags:
   *      - Categories
   *      responses:
   *        '200':
   *          description: Успешный запрос, получаем список категорий
   *        '500':
   *          description: Внутренняя ошибка сервера
   */
  getCategories: RequestHandler = async (req, res): Promise<void> => {
    const categories = await this.service.getCategories();
    res.send(categories);
  };

  /**
   * @swagger
   * /categories:
   *    post:
   *      summary: Создать новую категорию
   *      tags:
   *      - Categories
   *      requestBody:
   *        required: true
   *        content:
   *          application/json:
   *            schema:
   *              $ref: '#/components/schemas/CategoryDto'
   *      responses:
   *        '200':
   *          description: Успешный запрос, получаем список категорий
   *        '500':
   *          description: Внутренняя ошибка сервера
   */
  createCategory: RequestHandler = async (req, res): Promise<void> => {
    const categoryDto = plainToInstance(CategoryDto, req.body);
    const category = await this.service.createCategory(categoryDto);
    res.send(category);
  };
}
